from __future__ import print_function

import unittest

from fobi.tests.test_browser_build_dynamic_forms import *

# from fobi.tests.test_core import *
# from fobi.tests.test_dynamic_forms import *
# from fobi.tests.test_sortable_dict import *

__title__ = "fobi.tests"
__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2014-2019 Artur Barseghyan"
__license__ = "GPL 2.0/LGPL 2.1"

if __name__ == "__main__":
    unittest.main()
